@@ -3,8 +3,9 @@ import os
 import time
 import yaml
 import datetime
+import tarfile
+import shutil
 from typeguard import typechecked
-from tenacity import retry, stop_after_attempt
 
 from benchmark_runner.common.logger.logger_time_stamp import logger_time_stamp, logger
 from benchmark_runner.common.elasticsearch.elasticsearch_exceptions import ElasticSearchDataNotUploaded
@@ -16,6 +17,7 @@ from benchmark_runner.common.ssh.ssh import SSH
 from benchmark_runner.benchmark_operator.benchmark_operator_exceptions import OCSNonInstalled, SystemMetricsRequiredElasticSearch
 from benchmark_runner.main.environment_variables import environment_variables
 from benchmark_runner.common.clouds.IBM.ibm_operations import IBMOperations
+from benchmark_runner.common.clouds.shared.s3.s3_operations import S3Operations
 
 
 class BenchmarkOperatorWorkloads:
@@ -25,15 +27,19 @@ class BenchmarkOperatorWorkloads:
     def __init__(self, kubeadmin_password: str = '', es_host: str = '', es_port: str = ''):
         # environment variables
         self.__environment_variables_dict = environment_variables.environment_variables_dict
+        self.__time_stamp_format = self.__environment_variables_dict.get('time_stamp_format', '')
         self.__runner_version = self.__environment_variables_dict.get('build_version', '')
         self.__run_type = self.__environment_variables_dict.get('run_type', '')
         self.__system_metrics = self.__environment_variables_dict.get('system_metrics', '')
         self.__elasticsearch = self.__environment_variables_dict.get('elasticsearch', '')
+        self.__run_artifacts = self.__environment_variables_dict.get('run_artifacts_path', '')
+        self.__date_key = self.__environment_variables_dict.get('date_key', '')
+        self.__key = self.__environment_variables_dict.get('key', '')
         self.__ssh = SSH()
         self.__kubeadmin_password = kubeadmin_password
         self.__oc = OC(kubeadmin_password=self.__kubeadmin_password)
         self.__dir_path = f'{os.path.dirname(os.path.realpath(__file__))}'
-        self.__current_run_path = f'{self.__dir_path}/workload_flavors/{self.__run_type}/current_run'
+        self.__current_run_path = f'{self.__dir_path}/workload_flavors/current_run'
         self.__es_host = es_host
         self.__es_port = es_port
         if es_host and es_port:
@@ -155,7 +161,7 @@ class BenchmarkOperatorWorkloads:
         @return:
         """
         # delete benchmark-operator pod if exist
-        if self.__oc._is_pod_exist(pod_name='benchmark-controller-manager', namespace=environment_variables.environment_variables_dict['namespace']):
+        if self.__oc._is_pod_exist(pod_name='benchmark-controller-manager'):
             logger.info('make undeploy benchmark operator running pod')
             self.make_undeploy_benchmark_controller_manager(runner_path=runner_path)
 
@@ -228,26 +234,28 @@ class BenchmarkOperatorWorkloads:
     def system_metrics_collector(self, workload: str):
         """
         This method run system metrics collector
-        @param workload:
+        @param workload: the workload
         :return:
         """
+        if self.__run_type == 'test_ci':
+            es_index = 'system-metrics-test-ci'
+        else:
+            es_index = 'system-metrics'
         self.__oc.wait_for_pod_create(pod_name='system-metrics-collector')
         self.__oc.wait_for_initialized(label='app=system-metrics-collector', workload=workload)
         self.__oc.wait_for_pod_completed(label='app=system-metrics-collector', workload=workload)
         # verify that data upload to elastic search
         if self.__es_host:
-            if self.__run_type == 'test_ci':
-                es_index = 'system-metrics-test-ci'
-            else:
-                es_index = 'system-metrics'
             self.__es_operations.verify_es_data_uploaded(index=es_index,
                                                          uuid=self.__oc.get_long_uuid(workload=workload), fast_check=True)
 
-    def get_metadata(self, kind: str = None, database: str = None):
+    def get_metadata(self, kind: str = None, database: str = None, status: str = None, run_artifacts_url: str = None) -> dict:
         """
         This method return metadata kind and database argument are optional
         @param kind: optional: pod, vm, or kata
         @param database: optional:mssql, postgres or mariadb
+        @param status:
+        @param run_artifacts_url:
         :return:
         """
         date_format = '%Y_%m_%d'
@@ -260,6 +268,10 @@ class BenchmarkOperatorWorkloads:
                     'ci_date': datetime.datetime.now().strftime(date_format)}
         if kind:
             metadata.update({'kind': kind})
+        if status:
+            metadata.update({'run_status': status})
+        if run_artifacts_url:
+            metadata.update({'run_artifacts_url': run_artifacts_url})
         if database:
             metadata.update({'vm_os_version': 'centos8'})
         else:
@@ -295,43 +307,143 @@ class BenchmarkOperatorWorkloads:
         metadata.update({'status': status, 'status#': status_dict[status], 'ci_minutes_time': ci_minutes_time, 'benchmark_operator_id': benchmark_operator_id, 'benchmark_wrapper_id': benchmark_wrapper_id, 'ocp_install_minutes_time': ocp_install_minutes_time, 'ocp_resource_install_minutes_time': ocp_resource_install_minutes_time})
         self.__es_operations.upload_to_es(index='ci-status', data=metadata)
 
+    def __create_vm_log(self, labels: list):
+        """
+        This method set vm log per workload
+        :param labels: list of labels
+        :return:
+        """
+        for label in labels:
+            vm_name = self.__oc.get_vm(label=label)
+            self.__oc.save_vm_log(vm_name=vm_name)
+
+    def __create_pod_log(self, label: str = '', database: str = '') -> str:
+        """
+        This method create pod log per workload
+        :param label:pod label
+        :param database:
+        :return:
+        """
+        pod_name = self.__oc.get_pod(label=label, database=database)
+        if database:
+            self.__oc.save_pod_log(pod_name=pod_name, database=database)
+        else:
+            self.__oc.save_pod_log(pod_name=pod_name)
+
+    def __get_run_artifacts_hierarchy(self, workload_name: str = ''):
+        """
+        This method return log hierarchy
+        :param workload_name: workload name
+        :return:
+        """
+        key = self.__key
+        run_type = self.__run_type.replace('_', '-')
+        date_key = self.__date_key
+        if workload_name:
+            return os.path.join(key, run_type, date_key, workload_name)
+        return os.path.join(key, run_type, date_key)
+
+    def __create_run_artifacts(self, workload: str = '', database: str = '', labels: list = [], pod: bool = True):
+        """
+        This method create pod logs of benchmark-controller-manager, system-metrics and workload pod
+        :param workload: workload name
+        :param database: database name
+        :param pod: False in case of vm
+        :param labels: list of labels of pod names - using it when it different from workload name
+        :return: run artifacts url
+        """
+        self.__create_pod_log(label='benchmark-controller-manager')
+        self.__create_pod_log(label='system-metrics')
+        # for vm call to create_vm_log
+        if pod:
+            # workload that contains 2 pods
+            if labels:
+                for label in labels:
+                    self.__create_pod_log(label=label)
+            else:
+                self.__create_pod_log(label=workload)
+            if database:
+                self.__create_pod_log(database=database)
+        workload_name = self.__environment_variables_dict.get('workload', '').replace('_', '-')
+        return os.path.join(self.__environment_variables_dict.get('run_artifacts_url', ''), f'{self.__get_run_artifacts_hierarchy(workload_name=workload_name)}-{self.__time_stamp_format}.tar.gz')
+
+    def __make_run_artifacts_tarfile(self, workload: str):
+        """
+        This method tar.gz log path and return the tar.gz path
+        :return:
+        """
+        tar_run_artifacts_path = f"{self.__run_artifacts}.tar.gz"
+        with tarfile.open(tar_run_artifacts_path, mode='w:gz') as archive:
+            archive.add(self.__run_artifacts, arcname=f'{workload}-{self.__time_stamp_format}', recursive=True)
+        return tar_run_artifacts_path
+
+    @logger_time_stamp
+    def upload_run_artifacts_to_s3(self, workload: str):
+        """
+        This method uploads log to s3
+        :param workload:
+        :return:
+        """
+        s3operations = S3Operations()
+        # change workload to key convention
+        workload = workload.replace('_', '-')
+        tar_run_artifacts_path = self.__make_run_artifacts_tarfile(workload)
+        run_artifacts_hierarchy = self.__get_run_artifacts_hierarchy()
+        upload_file = f"{workload}-{self.__time_stamp_format}.tar.gz"
+        s3operations.upload_file(file_name_path=tar_run_artifacts_path,
+                                 bucket=self.__environment_variables_dict.get('bucket', ''),
+                                 key=run_artifacts_hierarchy,
+                                 upload_file=upload_file)
+        # remove local run artifacts workload folder
+        # verify that its not empty path
+        if len(self.__run_artifacts) > 3 and self.__run_artifacts != '/' and self.__run_artifacts and tar_run_artifacts_path and os.path.isfile(tar_run_artifacts_path):
+            # remove run_artifacts_path
+            shutil.rmtree(path=self.__run_artifacts)
+            # remove tar.gz file
+            os.remove(path=tar_run_artifacts_path)
+
+
+
 #***********************************************************************************************
 ######################################## Workloads #############################################
 #***********************************************************************************************
 
+
     @typechecked
     @logger_time_stamp
-    def stressng_pod(self, name: str=''):
+    def stressng_pod(self, name: str = ''):
         """
         This method run stressng workload
         :return:
         """
         try:
-            
             if name == '':
                 name = self.stressng_pod.__name__
             workload = name.replace('_', '-')
             kind = 'pod'
             if '_kata' in name:
                 kind = 'kata'
+            if self.__run_type == 'test_ci':
+                es_index = 'stressng-test-ci-results'
+            else:
+                es_index = 'stressng-results'
             environment_variables.environment_variables_dict['kind'] = kind
             self.__oc.create_pod_sync(yaml=os.path.join(f'{self.__current_run_path}', f'{self.stressng_pod.__name__}.yaml'), pod_name=f'{workload}-workload')
             self.__oc.wait_for_initialized(label='app=stressng_workload', workload=workload)
             self.__oc.wait_for_ready(label='app=stressng_workload', workload=workload)
-            self.__oc.wait_for_pod_completed(label='app=stressng_workload', workload=workload)
+            status = self.__oc.wait_for_pod_completed(label='app=stressng_workload', workload=workload)
+            status = 'complete' if status else 'failed'
             # system metrics
             if environment_variables.environment_variables_dict['system_metrics'] == 'True':
                 self.system_metrics_collector(workload=workload)
+            # save run artifacts logs
+            run_artifacts_url = self.__create_run_artifacts(workload=workload)
             if self.__es_host:
-                if self.__run_type == 'test_ci':
-                    es_index = 'stressng-test-ci-results'
-                else:
-                    es_index = 'stressng-results'
                 # verify that data upload to elastic search according to unique uuid
                 ids = self.__es_operations.verify_es_data_uploaded(index=es_index, uuid=self.__oc.get_long_uuid(workload=workload))
                 # update metadata
                 for id in ids:
-                    self.__es_operations.update_es_index(index=es_index, id=id, metadata=self.get_metadata(kind=kind))
+                    self.__es_operations.update_es_index(index=es_index, id=id, metadata=self.get_metadata(kind=kind, status=status, run_artifacts_url=run_artifacts_url))
             self.__oc.delete_pod_sync(
                 yaml=os.path.join(f'{self.__current_run_path}', f'{self.stressng_pod.__name__}.yaml'),
                 pod_name=f'{workload}-workload')
@@ -340,6 +452,9 @@ class BenchmarkOperatorWorkloads:
                                            pod_name=f'{workload}-workload')
             raise err
         except Exception as err:
+            # save run artifacts logs
+            run_artifacts_url = self.__create_run_artifacts(workload=workload)
+            self.__es_operations.upload_to_es(index=es_index, data=self.get_metadata(kind=kind, status='failed', run_artifacts_url=run_artifacts_url))
             self.tear_down_pod_after_error(yaml=os.path.join(f'{self.__current_run_path}', f'{self.stressng_pod.__name__}.yaml'),
                                            pod_name=f'{workload}-workload')
             raise err
@@ -360,25 +475,30 @@ class BenchmarkOperatorWorkloads:
         :return:
         """
         try:
+            if self.__run_type == 'test_ci':
+                es_index = 'stressng-test-ci-results'
+            else:
+                es_index = 'stressng-results'
             workload = self.stressng_vm.__name__.replace('_', '-')
             environment_variables.environment_variables_dict['kind'] = 'vm'
             self.__oc.create_vm_sync(yaml=os.path.join(f'{self.__current_run_path}', f'{self.stressng_vm.__name__}.yaml'), vm_name=f'{workload}-workload')
             self.__oc.wait_for_initialized(label='app=stressng_workload', workload=workload)
             self.__oc.wait_for_ready(label='app=stressng_workload', workload=workload)
-            self.__oc.wait_for_vm_completed(workload=workload)
+            # Create vm log should be direct after vm is ready
+            self.__create_vm_log(labels=[workload])
+            status = self.__oc.wait_for_vm_completed(workload=workload)
+            status = 'complete' if status else 'failed'
             # system metrics
             if environment_variables.environment_variables_dict['system_metrics'] == 'True':
-               self.system_metrics_collector(workload=workload)
+                self.system_metrics_collector(workload=workload)
+            # save run artifacts logs of benchmark-controller-manager and system-metrics
+            run_artifacts_url = self.__create_run_artifacts(workload=workload, pod=False)
             # verify that data upload to elastic search
             if self.__es_host:
-                if self.__run_type == 'test_ci':
-                    es_index = 'stressng-test-ci-results'
-                else:
-                    es_index = 'stressng-results'
                 ids = self.__es_operations.verify_es_data_uploaded(index=es_index, uuid=self.__oc.get_long_uuid(workload=workload))
                 # update metadata
                 for id in ids:
-                    self.__es_operations.update_es_index(index=es_index, id=id, metadata=self.get_metadata(kind='vm'))
+                    self.__es_operations.update_es_index(index=es_index, id=id, metadata=self.get_metadata(kind=self.__environment_variables_dict.get('kind', ''), status=status, run_artifacts_url=run_artifacts_url))
             self.__oc.delete_vm_sync(
                 yaml=os.path.join(f'{self.__current_run_path}', f'{self.stressng_vm.__name__}.yaml'),
                 vm_name=f'{workload}-workload')
@@ -387,13 +507,16 @@ class BenchmarkOperatorWorkloads:
                                           vm_name=f'{workload}-workload')
             raise err
         except Exception as err:
+            # save run artifacts logs
+            run_artifacts_url = self.__create_run_artifacts(workload=workload, pod=False)
+            self.__es_operations.upload_to_es(index=es_index, data=self.get_metadata(kind=self.__environment_variables_dict.get('kind', ''), status='failed', run_artifacts_url=run_artifacts_url))
             self.tear_down_vm_after_error(yaml=os.path.join(f'{self.__current_run_path}', f'{self.stressng_vm.__name__}.yaml'),
                                           vm_name=f'{workload}-workload')
             raise err
 
     @typechecked
     @logger_time_stamp
-    def uperf_pod(self, name: str=''):
+    def uperf_pod(self, name: str = ''):
         """
         This method run uperf workload
         :return:
@@ -405,6 +528,10 @@ class BenchmarkOperatorWorkloads:
             kind = 'pod'
             if '_kata' in name:
                 kind = 'kata'
+            if self.__run_type == 'test_ci':
+                es_index = 'uperf-test-ci-results'
+            else:
+                es_index = 'uperf-results'
             environment_variables.environment_variables_dict['kind'] = kind
             self.__oc.create_pod_sync(yaml=os.path.join(f'{self.__current_run_path}', f'{self.uperf_pod.__name__}.yaml'), pod_name=f'uperf-server')
             # uperf server
@@ -422,23 +549,22 @@ class BenchmarkOperatorWorkloads:
                 self.__oc.wait_for_initialized(label=label, workload=workload, label_uuid=False)
                 self.__oc.wait_for_ready(label=label, workload=workload, label_uuid=False)
             # uperf client
-            self.__oc.wait_for_pod_create(pod_name=f'uperf-client')
+            self.__oc.wait_for_pod_create(pod_name='uperf-client')
             self.__oc.wait_for_initialized(label='app=uperf-bench-client', workload=workload)
             self.__oc.wait_for_ready(label='app=uperf-bench-client', workload=workload)
-            self.__oc.wait_for_pod_completed(label='app=uperf-bench-client', workload=workload)
+            status = self.__oc.wait_for_pod_completed(label='app=uperf-bench-client', workload=workload)
+            status = 'complete' if status else 'failed'
             # system metrics
             if environment_variables.environment_variables_dict['system_metrics'] == 'True':
                 self.system_metrics_collector(workload=workload)
+            # save run artifacts logs
+            run_artifacts_url = self.__create_run_artifacts(workload=workload, labels=['uperf-client', 'uperf-server'])
             if self.__es_host:
-                if self.__run_type == 'test_ci':
-                    es_index = 'uperf-test-ci-results'
-                else:
-                    es_index = 'uperf-results'
                 # verify that data upload to elastic search
                 ids = self.__es_operations.verify_es_data_uploaded(index=es_index, uuid=self.__oc.get_long_uuid(workload=workload), workload=name)
                 # update metadata
                 for id in ids:
-                    self.__es_operations.update_es_index(index=es_index, id=id, metadata=self.get_metadata(kind=kind))
+                    self.__es_operations.update_es_index(index=es_index, id=id, metadata=self.get_metadata(kind=kind, status=status, run_artifacts_url=run_artifacts_url))
             self.__oc.delete_pod_sync(
                 yaml=os.path.join(f'{self.__current_run_path}', f'{self.uperf_pod.__name__}.yaml'),
                 pod_name=f'uperf-client')
@@ -446,6 +572,9 @@ class BenchmarkOperatorWorkloads:
             self.tear_down_pod_after_error(yaml=os.path.join(f'{self.__current_run_path}', f'{self.uperf_pod.__name__}.yaml'), pod_name=f'uperf-client')
             raise err
         except Exception as err:
+            # save run artifacts logs
+            run_artifacts_url = self.__create_run_artifacts(workload=workload, labels=['uperf-client', 'uperf-server'])
+            self.__es_operations.upload_to_es(index=es_index, data=self.get_metadata(kind=kind, status='failed', run_artifacts_url=run_artifacts_url))
             self.tear_down_pod_after_error(yaml=os.path.join(f'{self.__current_run_path}', f'{self.uperf_pod.__name__}.yaml'), pod_name=f'uperf-client')
             raise err
 
@@ -464,6 +593,10 @@ class BenchmarkOperatorWorkloads:
         :return:
         """
         try:
+            if self.__run_type == 'test_ci':
+                es_index = 'uperf-test-ci-results'
+            else:
+                es_index = 'uperf-results'
             workload = self.uperf_vm.__name__.replace('_', '-')
             environment_variables.environment_variables_dict['kind'] = 'vm'
             self.__oc.create_vm_sync(yaml=os.path.join(f'{self.__current_run_path}', f'{self.uperf_vm.__name__}.yaml'), vm_name='uperf-server')
@@ -475,32 +608,36 @@ class BenchmarkOperatorWorkloads:
             self.__oc.wait_for_vm_create(vm_name='uperf-client')
             self.__oc.wait_for_initialized(label='app=uperf-bench-client', workload=workload)
             self.__oc.wait_for_ready(label='app=uperf-bench-client', workload=workload)
-            self.__oc.wait_for_vm_completed(workload=workload)
+            # Create vm log should be direct after vm is ready
+            self.__create_vm_log(labels=['uperf-server', 'uperf-client'])
+            status = self.__oc.wait_for_vm_completed(workload=workload)
+            status = 'complete' if status else 'failed'
             # system metrics
             if environment_variables.environment_variables_dict['system_metrics'] == 'True':
                 self.system_metrics_collector(workload=workload)
+            # save run artifacts logs of benchmark-controller-manager and system-metrics
+            run_artifacts_url = self.__create_run_artifacts(workload=workload, pod=False)
             # verify that data upload to elastic search
             if self.__es_host:
-                if self.__run_type == 'test_ci':
-                    es_index = 'uperf-test-ci-results'
-                else:
-                    es_index = 'uperf-results'
                 ids = self.__es_operations.verify_es_data_uploaded(index=es_index, uuid=self.__oc.get_long_uuid(workload=workload), workload=self.uperf_vm.__name__)
                 # update metadata
                 for id in ids:
-                    self.__es_operations.update_es_index(index=es_index, id=id, metadata=self.get_metadata(kind='vm'))
+                    self.__es_operations.update_es_index(index=es_index, id=id, metadata=self.get_metadata(kind=self.__environment_variables_dict.get('kind', ''), status=status, run_artifacts_url=run_artifacts_url))
             self.__oc.delete_vm_sync(yaml=os.path.join(f'{self.__current_run_path}', f'{self.uperf_vm.__name__}.yaml'),
                                      vm_name='uperf-server')
         except ElasticSearchDataNotUploaded as err:
             self.tear_down_vm_after_error(yaml=os.path.join(f'{self.__current_run_path}', f'{self.uperf_vm.__name__}.yaml'), vm_name='uperf-server')
             raise err
         except Exception as err:
+            # save run artifacts logs of benchmark-controller-manager and system-metrics
+            run_artifacts_url = self.__create_run_artifacts(workload=workload, pod=False)
+            self.__es_operations.upload_to_es(index=es_index, data=self.get_metadata(kind=self.__environment_variables_dict.get('kind', ''), status=status, run_artifacts_url=run_artifacts_url))
             self.tear_down_vm_after_error(yaml=os.path.join(f'{self.__current_run_path}', f'{self.uperf_vm.__name__}.yaml'), vm_name='uperf-server')
             raise err
 
     @typechecked
     @logger_time_stamp
-    def hammerdb_pod(self, database: str, name: str=''):
+    def hammerdb_pod(self, database: str, name: str = ''):
         """
         This method run hammerdb pod workload
         :return:
@@ -512,6 +649,10 @@ class BenchmarkOperatorWorkloads:
             kind = 'pod'
             if '_kata' in name:
                 kind = 'kata'
+            if self.__run_type == 'test_ci':
+                es_index = 'hammerdb-test-ci-results'
+            else:
+                es_index = 'hammerdb-results'
             environment_variables.environment_variables_dict['kind'] = kind
             # database
             self.__oc.create_pod_sync(yaml=os.path.join(f'{self.__current_run_path}', f'{database}.yaml'), pod_name=database, namespace=f'{database}-db')
@@ -528,20 +669,19 @@ class BenchmarkOperatorWorkloads:
             self.__oc.wait_for_pod_create(pod_name=f'{workload}-workload')
             self.__oc.wait_for_initialized(label='app=hammerdb_workload', workload=workload)
             self.__oc.wait_for_ready(label='app=hammerdb_workload', workload=workload)
-            self.__oc.wait_for_pod_completed(label='app=hammerdb_workload', workload=workload)
+            status = self.__oc.wait_for_pod_completed(label='app=hammerdb_workload', workload=workload)
+            status = 'complete' if status else 'failed'
             # system metrics
             if environment_variables.environment_variables_dict['system_metrics'] == 'True':
                 self.system_metrics_collector(workload=workload)
+            # save run artifacts logs
+            run_artifacts_url = self.__create_run_artifacts(labels=[f'{workload}-creator', f'{workload}-workload'], database=database)
             if self.__es_host:
-                if self.__run_type == 'test_ci':
-                    es_index = 'hammerdb-test-ci-results'
-                else:
-                    es_index = 'hammerdb-results'
                 # verify that data upload to elastic search
                 ids = self.__es_operations.verify_es_data_uploaded(index=es_index, uuid=self.__oc.get_long_uuid(workload=workload))
                 # update metadata
                 for id in ids:
-                    self.__es_operations.update_es_index(index=es_index, id=id, metadata=self.get_metadata(kind=kind, database=database))
+                    self.__es_operations.update_es_index(index=es_index, id=id, metadata=self.get_metadata(kind=kind, database=database, status=status, run_artifacts_url=run_artifacts_url))
             # delete hammerdb
             self.__oc.delete_pod_sync(
                 yaml=os.path.join(f'{self.__current_run_path}', f'{self.hammerdb_pod.__name__}_{database}.yaml'),
@@ -559,6 +699,9 @@ class BenchmarkOperatorWorkloads:
                                       namespace=f'{database}-db')
             raise err
         except Exception as err:
+            # save run artifacts logs
+            run_artifacts_url = self.__create_run_artifacts(labels=[f'{workload}-creator', f'{workload}-workload'], database=database)
+            self.__es_operations.upload_to_es(index=es_index, data=self.get_metadata(kind=kind, database=database, status='failed', run_artifacts_url=run_artifacts_url))
             # delete hammerdb
             self.tear_down_pod_after_error(yaml=os.path.join(f'{self.__current_run_path}', f'{self.hammerdb_pod.__name__}_{database}.yaml'),
                                            pod_name=f'{workload}-creator')
@@ -584,6 +727,10 @@ class BenchmarkOperatorWorkloads:
         :return:
         """
         try:
+            if self.__run_type == 'test_ci':
+                es_index = 'hammerdb-test-ci-results'
+            else:
+                es_index = 'hammerdb-results'
             workload = self.hammerdb_vm.__name__.replace('_', '-')
             environment_variables.environment_variables_dict['kind'] = 'vm'
             self.__oc.create_vm_sync(yaml=os.path.join(f'{self.__current_run_path}', f'{self.hammerdb_vm.__name__}_{database}.yaml'), vm_name=f'{workload}-workload')
@@ -591,20 +738,21 @@ class BenchmarkOperatorWorkloads:
             self.__oc.wait_for_vm_create(vm_name=f'{workload}-workload')
             self.__oc.wait_for_initialized(label='app=hammerdb_workload', workload=workload)
             self.__oc.wait_for_ready(label='app=hammerdb_workload', workload=workload)
-            self.__oc.wait_for_vm_completed(workload=workload)
+            # Create vm log should be direct after vm is ready
+            self.__create_vm_log(labels=[workload])
+            status = self.__oc.wait_for_vm_completed(workload=workload)
+            status = 'complete' if status else 'failed'
             # system metrics
             if environment_variables.environment_variables_dict['system_metrics'] == 'True':
                 self.system_metrics_collector(workload=workload)
+            # save run artifacts logs of benchmark-controller-manager and system-metrics
+            run_artifacts_url = self.__create_run_artifacts(workload=workload, pod=False)
             # verify that data upload to elastic search
             if self.__es_host:
-                if self.__run_type == 'test_ci':
-                    es_index = 'hammerdb-test-ci-results'
-                else:
-                    es_index = 'hammerdb-results'
                 ids = self.__es_operations.verify_es_data_uploaded(index=es_index, uuid=self.__oc.get_long_uuid(workload=workload))
                 # update metadata
                 for id in ids:
-                    self.__es_operations.update_es_index(index=es_index, id=id, metadata=self.get_metadata(kind='vm', database=database))
+                    self.__es_operations.update_es_index(index=es_index, id=id, metadata=self.get_metadata(kind=self.__environment_variables_dict.get('kind', ''), database=database, status=status, run_artifacts_url=run_artifacts_url))
             self.__oc.delete_vm_sync(
                 yaml=os.path.join(f'{self.__current_run_path}', f'{self.hammerdb_vm.__name__}_{database}.yaml'),
                 vm_name=f'{workload}-workload')
@@ -613,6 +761,9 @@ class BenchmarkOperatorWorkloads:
                                           vm_name=f'{workload}-workload')
             raise VMNotCompletedTimeout(workload=workload)
         except Exception as err:
+            run_artifacts_url = self.__create_run_artifacts(workload=workload, pod=False)
+            self.__es_operations.upload_to_es(index=es_index, data=self.get_metadata(kind=self.__environment_variables_dict.get('kind', ''), database=database, status=status, run_artifacts_url=run_artifacts_url))
+            # delete hammerdb
             self.tear_down_vm_after_error(yaml=os.path.join(f'{self.__current_run_path}', f'{self.hammerdb_vm.__name__}_{database}.yaml'),
                                           vm_name=f'{workload}-workload')
             raise err
@@ -633,23 +784,21 @@ class BenchmarkOperatorWorkloads:
         self.remove_if_exist_run_yaml()
         workload_name = workload_full_name.split('_')
 
+        self.__template.generate_yamls(workload=workload_full_name)
         if 'hammerdb' in workload_full_name:
             # check if ocs is installed
             if self.__environment_variables_dict.get('ocs_pvc', '') == 'True':
                 if not self.__oc.is_ocs_installed():
                     raise OCSNonInstalled()
-            self.__template.generate_hammerdb_yamls(workload=f'{workload_name[0]}_{workload_name[1]}', database=workload_name[2])
             class_method = getattr(BenchmarkOperatorWorkloads, f'{workload_name[0]}_{workload_name[1]}')
             class_method(self, workload_name[2])
         else:
-            self.__template.generate_workload_yamls(workload=workload_full_name)
             class_method = getattr(BenchmarkOperatorWorkloads, workload_full_name)
             class_method(self)
         # remove workload yaml at the end of run
         self.__remove_run_workload_yaml_file(workload_full_name=workload_full_name)
 
     @logger_time_stamp
-    @retry(stop=stop_after_attempt(3))
     def run_workload(self, workload: str):
         """
         This method run the input workload
@@ -668,6 +817,9 @@ class BenchmarkOperatorWorkloads:
         # run workload
         self.run_workload_func(workload_full_name=workload)
 
+        # upload logs to s3
+        self.upload_run_artifacts_to_s3(workload=workload)
+
         # make undeploy benchmark controller manager
         self.make_undeploy_benchmark_controller_manager(runner_path=environment_variables.environment_variables_dict['runner_path'])
 
