@@ -2,24 +2,32 @@
 import subprocess
 from benchmark_runner.common.logger.logger_time_stamp import logger
 from benchmark_runner.common.ssh.ssh_exceptions import SSHSubprocessError
+from benchmark_runner.main.environment_variables import environment_variables
 
 
 class SSH:
     """
     This class run local SSH commands
     """
-    def __init__(self, timeout: int = 300):
-        self.timeout = timeout
+    def __init__(self):
+        self.__environment_variables_dict = environment_variables.environment_variables_dict
+        self.timeout = int(self.__environment_variables_dict.get('timeout', 300))
 
-    def run(self, cmd: str, is_check: bool = False):
+    def run(self, cmd: str, is_check: bool = False, background: bool = False):
         """
         This method run shell commands
+        :param background: run ssh in background
         :param cmd:
         :param is_check:run check command
         :return:
         """
         try:
-            if is_check:
+            if background:
+                # DEVNULL - hide stdout
+                output = subprocess.Popen(
+                    cmd, stdout=subprocess.DEVNULL, stderr=subprocess.DEVNULL,
+                    shell=True)
+            elif is_check:
                 output = subprocess.check_output(
                     cmd,
                     stderr=subprocess.STDOUT,
